SaeFeature

Struct SaeFeature 

pub struct SaeFeature {
    pub driver_handler_supported: Option<bool>,
    pub sme_handler_supported: Option<bool>,
    pub hash_to_element_supported: Option<bool>,
    /* private fields */
}
Simultaneous Authentication of Equals. See IEEE 802.11-2016 12.4. This is a security feature, usable for fullmac or softmac.

Fields

driver_handler_supported: Option<bool>

SAE can be handled by the driver.

sme_handler_supported: Option<bool>

SAE can be handled by SME.

hash_to_element_supported: Option<bool>

Indicates whether the driver is compatible with SAE hash-to-element. In the SME handler case, this just means passing through SAE frames with the SAE_HASH_TO_ELEMENT status code.